local myname="ZifnabsMapper"
local Me=CreateFrame("Frame",myname)
if not ZifnabsMod then ZifnabsMod={map=Me} else ZifnabsMod.map=Me end
local mod
local L
local C
local db

local worldmapPins={}
local uimid2znr={}
local widget={show={},text={}}
local selector={}

Me.WorldMapDataProvider = CreateFromMixins(MapCanvasDataProviderMixin)
ZifnabsWorldmapPinMixin = CreateFromMixins(MapCanvasPinMixin)

-- --------------------------------------------------------------------------------------
-- INITIALIZE
-- --------------------------------------------------------------------------------------
function Me:Initialize(fwinfo)
	mod=fwinfo.mod
	L=fwinfo.L
	C=fwinfo.C
	db=fwinfo.db
	for znr,info in pairs(C.zones) do
		if info.mid then uimid2znr[info.mid]=znr end
	end
end
function Me:PostInit() 
	WorldMapFrame:AddDataProvider(Me.WorldMapDataProvider)
	Me.WorldMapDataProvider:RefreshAllData() 
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP DATAPROVIDER : REMOVE ALL DATA
-- --------------------------------------------------------------------------------------
function Me.WorldMapDataProvider:RemoveAllData()
	self:GetMap():RemoveAllPinsByTemplate("ZifnabsWorldmapPinTemplate")
	wipe(worldmapPins)
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP DATAPROVIDER : REFRESH ALL DATA
-- --------------------------------------------------------------------------------------
function Me.WorldMapDataProvider:RefreshAllData(fromOnShow)
	self:RemoveAllData()
	local uiMapID = self:GetMap():GetMapID()
	if uiMapID then
		local zone_nr=uimid2znr[uiMapID]
		if not zone_nr then
			mod.f:Print("Unbekannte Kartenzone "..uiMapID)
		else
			local interested=mod.loc:WORLDMAP_ZONE_CHANGED(zone_nr)
			local categories={}
			for modname,info in pairs(interested) do
				for nr,data in pairs(info.list or {}) do
					if selector[data.category]==nil then
						selector[data.category]=true
					end
					if categories[data.category]==nil then
						categories[data.category]=selector[data.category]
					end
					if categories[data.category] then
						table.insert(worldmapPins, self:GetMap():AcquirePin("ZifnabsWorldmapPinTemplate", data))
					end
				end
			end
			for category,selected in pairs(selector) do
				if categories[category]==nil then 
					selector[category]=nil 
				end
			end

			local nr=0
			for category,show in pairs(categories) do
				nr=nr+1
				if not widget.show[nr] then
					widget.show[nr]=mod.ui:newCheck(myname.."_Show_"..nr,20,20,WorldMapFrame.ScrollContainer,"BOTTOMLEFT","BOTTOMLEFT",60+120*nr,5,{text="xxx",tt=L.msg.mapperselect,check=true,click=Me.ReSelect})
					widget.show[nr]:SetParent(WorldMapFrame)
					widget.show[nr].category=category
					widget.text[nr]=getglobal(myname.."_Show_"..nr.."Text")
					widget.show.max=nr
				end
				widget.text[nr]:SetText(category)
				widget.show[nr]:SetChecked(show)
				widget.show[nr]:Show()
			end
			if widget.show.max then 
				for h=nr+1,widget.show.max,1 do
					widget.show[h]:Hide()
				end
			end
		end
	end
end

function Me:ReSelect(checkbox)
	selector[checkbox.category]=checkbox:GetChecked()
	Me.WorldMapDataProvider:RefreshAllData()
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP PIN MIXIN : ON LOAD
-- --------------------------------------------------------------------------------------
function ZifnabsWorldmapPinMixin:OnLoad()
	self:UseFrameLevelType("PIN_FRAME_LEVEL_AREA_POI")
	self:SetScalingLimits(1, 1.0, 1.2);
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP PIN MIXIN : ON ACQUIRED
-- --------------------------------------------------------------------------------------
function ZifnabsWorldmapPinMixin:OnAcquired(data,icon) -- mal schauen welche infos hier rein sollen
	local x,y,zone,zone_nr=mod.loc:ParseLoc(data.pos)
	self:SetPosition(x/100., y/100.)
	self.tooltipText=data.tooltip or data.text
	if data.addpos then
		self.tooltipText=(self.tooltipText or "").." ("..x.."/"..y..")"
	end
	self.click=data.click
	self.data=data
	if data.icon then 
		local iconname="Interface/AddOns/Zifnabs/Icons/"..data.icon..".tga"
--TBC		self:SetBackdrop(nil)
		self.texture:SetTexture(iconname)
		self:SetSize(data.size or 12,data.size or 12)
	else
--TBC		self:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", edgeFile = nil});
		self.texture:SetTexture(nil)
		self:SetSize(data.size or 8,data.size or 8)
--		self.texture:SetTexture("Interface/AddOns/Zifnabs/Icons/Other/target.tga") --TBC
		self.texture:SetTexture(135725) --TBC
--TBC		self:SetBackdropColor(1,0,0,1)
	end
	self:EnableMouse(true)
	self:Show()
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP PIN MIXIN : ON MOUSE EVENTS
-- --------------------------------------------------------------------------------------
function ZifnabsWorldmapPinMixin:OnMouseEnter()
	mod.ui:Tooltip(self)
end
function ZifnabsWorldmapPinMixin:OnMouseLeave() 
	GameTooltip:Hide()
end
function ZifnabsWorldmapPinMixin:OnClick(button) 
end